==> haskell-blaze-html-0.9.1.1-4-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-blaze-html.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: blaze-html
version: 0.9.1.1
id: blaze-html-0.9.1.1-20cHaEyBGNsGxpPmCtOdMq
key: blaze-html-0.9.1.1-20cHaEyBGNsGxpPmCtOdMq
license: BSD-3-Clause
maintainer: Jasper Van der Jeugt <m@jaspervdj.be>
author: Jasper Van der Jeugt, Simon Meier
stability: Experimental
homepage: http://jaspervdj.be/blaze
synopsis: A blazingly fast HTML combinator library for Haskell
description:
    A blazingly fast HTML combinator library for the Haskell
    programming language. The Text.Blaze module is a good
    starting point, as well as this tutorial:
    <http://jaspervdj.be/blaze/tutorial.html>.
category: Text
abi: 7047caae57386baf49e8a9f0b929d8b4
exposed: True
exposed-modules:
    Text.Blaze.Html Text.Blaze.Html.Renderer.Pretty
    Text.Blaze.Html.Renderer.String Text.Blaze.Html.Renderer.Text
    Text.Blaze.Html.Renderer.Utf8 Text.Blaze.Html4.FrameSet
    Text.Blaze.Html4.FrameSet.Attributes Text.Blaze.Html4.Strict
    Text.Blaze.Html4.Strict.Attributes Text.Blaze.Html4.Transitional
    Text.Blaze.Html4.Transitional.Attributes Text.Blaze.Html5
    Text.Blaze.Html5.Attributes Text.Blaze.XHtml1.FrameSet
    Text.Blaze.XHtml1.FrameSet.Attributes Text.Blaze.XHtml1.Strict
    Text.Blaze.XHtml1.Strict.Attributes Text.Blaze.XHtml1.Transitional
    Text.Blaze.XHtml1.Transitional.Attributes Text.Blaze.XHtml5
    Text.Blaze.XHtml5.Attributes
import-dirs: /usr/lib/ghc-8.4.3/site-local/blaze-html-0.9.1.1
library-dirs: /usr/lib/ghc-8.4.3/site-local/blaze-html-0.9.1.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.4.3/blaze-html-0.9.1.1
hs-libraries: HSblaze-html-0.9.1.1-20cHaEyBGNsGxpPmCtOdMq
depends:
    base-4.11.1.0 blaze-builder-0.4.1.0-Gz7BwSYlOrTDOutVN7e028
    blaze-markup-0.8.2.1-FFkiru1HsegAfMrnqJMDug bytestring-0.10.8.2
    text-1.2.3.0
abi-depends: base-4.11.1.0=9da3f387598d41928f3ebf8097acf9b3
             blaze-builder-0.4.1.0-Gz7BwSYlOrTDOutVN7e028=84ea2e9d87e56b4ceb814f92752c9208
             blaze-markup-0.8.2.1-FFkiru1HsegAfMrnqJMDug=18a52ecde9bf04c66bdf9a0cefc08348
             bytestring-0.10.8.2=76943c00398d547fb172e56c2f93c635
             text-1.2.3.0=be4c3e1c57cff1d501eb0e876706a48d
haddock-interfaces: /usr/share/doc/haskell-blaze-html/html/blaze-html.haddock
haddock-html: /usr/share/doc/haskell-blaze-html/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-blaze-html-0.9.1.1-6-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-blaze-html.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: blaze-html
version: 0.9.1.1
id: blaze-html-0.9.1.1-9KckvR0hMlDAKmgKiXoWpy
key: blaze-html-0.9.1.1-9KckvR0hMlDAKmgKiXoWpy
license: BSD-3-Clause
maintainer: Jasper Van der Jeugt <m@jaspervdj.be>
author: Jasper Van der Jeugt, Simon Meier
stability: Experimental
homepage: http://jaspervdj.be/blaze
synopsis: A blazingly fast HTML combinator library for Haskell
description:
    A blazingly fast HTML combinator library for the Haskell
    programming language. The Text.Blaze module is a good
    starting point, as well as this tutorial:
    <http://jaspervdj.be/blaze/tutorial.html>.
category: Text
abi: 91214646240ea86cd8d931e54e0af570
exposed: True
exposed-modules:
    Text.Blaze.Html Text.Blaze.Html.Renderer.Pretty
    Text.Blaze.Html.Renderer.String Text.Blaze.Html.Renderer.Text
    Text.Blaze.Html.Renderer.Utf8 Text.Blaze.Html4.FrameSet
    Text.Blaze.Html4.FrameSet.Attributes Text.Blaze.Html4.Strict
    Text.Blaze.Html4.Strict.Attributes Text.Blaze.Html4.Transitional
    Text.Blaze.Html4.Transitional.Attributes Text.Blaze.Html5
    Text.Blaze.Html5.Attributes Text.Blaze.XHtml1.FrameSet
    Text.Blaze.XHtml1.FrameSet.Attributes Text.Blaze.XHtml1.Strict
    Text.Blaze.XHtml1.Strict.Attributes Text.Blaze.XHtml1.Transitional
    Text.Blaze.XHtml1.Transitional.Attributes Text.Blaze.XHtml5
    Text.Blaze.XHtml5.Attributes
import-dirs: /usr/lib/ghc-8.4.3/site-local/blaze-html-0.9.1.1
library-dirs: /usr/lib/ghc-8.4.3/site-local/blaze-html-0.9.1.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.4.3/blaze-html-0.9.1.1
hs-libraries: HSblaze-html-0.9.1.1-9KckvR0hMlDAKmgKiXoWpy
depends:
    base-4.11.1.0 blaze-builder-0.4.1.0-Gz7BwSYlOrTDOutVN7e028
    blaze-markup-0.8.2.1-FFkiru1HsegAfMrnqJMDug bytestring-0.10.8.2
    text-1.2.3.0
abi-depends: base-4.11.1.0=9da3f387598d41928f3ebf8097acf9b3
             blaze-builder-0.4.1.0-Gz7BwSYlOrTDOutVN7e028=84ea2e9d87e56b4ceb814f92752c9208
             blaze-markup-0.8.2.1-FFkiru1HsegAfMrnqJMDug=18a52ecde9bf04c66bdf9a0cefc08348
             bytestring-0.10.8.2=76943c00398d547fb172e56c2f93c635
             text-1.2.3.0=be4c3e1c57cff1d501eb0e876706a48d
haddock-interfaces: /usr/share/doc/haskell-blaze-html/html/blaze-html.haddock
haddock-html: /usr/share/doc/haskell-blaze-html/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
